#
# spec file for package java-cup
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _without_bootstrap 1
%define cvs_version        11b
%define real_name   java-cup
%define git_hash d69c832
%define git_date 20210814
%bcond_with                bootstrap
Name:           java-cup
Version:        0.11
Release:        33.6
Summary:        LALR Parser Generator in Java
License:        HPND
Group:          Development/Libraries/Java
URL:            https://www2.cs.tum.edu/projects/cup/
Source0:        %{real_name}-%{git_hash}.tar.xz
Source1:        %{real_name}-generated-files.tar.xz
Source100:      java-cup-nogit.patch.in
Patch0:         java-cup-no-classpath-in-manifest.patch
Patch1:         java-cup-java8.patch
Patch2:         java-cup-no-cup-no-jflex.patch
Patch3:         java-cup-classpath.patch
BuildRequires:  ant
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  xml-commons-apis-bootstrap
BuildRequires:  xml-commons-resolver-bootstrap
#!BuildIgnore:  xalan-j2
#!BuildIgnore:  xerces-j2
#!BuildIgnore:  xml-commons-apis
#!BuildIgnore:  xml-commons-resolver
Obsoletes:      java_cup < %{version}-%{release}
Provides:       java_cup = %{version}-%{release}
BuildArch:      noarch
%if %{without bootstrap}
BuildRequires:  java-cup-bootstrap
BuildRequires:  javapackages-local
BuildRequires:  jflex-bootstrap
Conflicts:      java-cup-bootstrap
%else
Conflicts:      java-cup
%endif

%description
java-cup is a LALR Parser Generator in Java. With v0.11, you can: *
   use CUP in an Ant-Target

* start CUP by a simple command like java -jar java-cup-11a.jar
   myGrammar.cup

* use generic parametrized classes (since Java 1.5) as datatypes for
   non terminals and terminals

* have Your own symbol classes

%if %{without bootstrap}
%package manual
Summary:        LALR Parser Generator in Java
Group:          Development/Libraries/Java

%description manual
java-cup is a LALR Parser Generator in Java. With v0.11, you can: *
   use CUP in an Ant-Target

* start CUP by a simple command like java -jar java-cup-11a.jar
   myGrammar.cup

* use generic parametrized classes (since Java 1.5) as datatypes for
   non

* terminals and terminals

* have Your own symbol classes

%endif

%prep
%setup -q -n %{real_name}-%{git_hash}
cat %{SOURCE100} | sed 's#@GIT_HASH@#%{git_hash}#g' | sed 's#@GIT_DATE@#%{git_date}#g' | patch -p1 -u -l
%patch -P 0 -p1
%patch -P 1 -p1
%if %{with bootstrap}
%setup -q -T -D -a 1 -n %{real_name}-%{git_hash}
%patch -P 2 -p1
%else
%patch -P 3 -p1
%endif
find . -name '*.jar' -print -delete
mkdir -p target/classes

%build
%if %{with bootstrap}
export CLASSPATH=
%else
export CLASSPATH=$(build-classpath java-cup jflex)
%endif
export OPT_JAR_LIST=:
ant

%install
# jar
mkdir -p %{buildroot}%{_javadir}
cp -a target/dist/%{real_name}-%{cvs_version}.jar %{buildroot}%{_javadir}/%{real_name}.jar
cp -a target/dist/%{real_name}-%{cvs_version}-runtime.jar %{buildroot}%{_javadir}/%{real_name}-runtime.jar

%if %{without bootstrap}
# maven data
%add_maven_depmap com.github.vbmacher:%{real_name}:%{cvs_version}-%{git_date} %{real_name}.jar
%add_maven_depmap com.github.vbmacher:%{real_name}-runtime:%{cvs_version}-%{git_date} %{real_name}-runtime.jar
%endif

# compatibility symlinks
(cd %{buildroot}%{_javadir} && ln -s %{real_name}.jar java_cup.jar && ln -s %{real_name}-runtime.jar java_cup-runtime.jar)
mkdir -p %{buildroot}%{_bindir}

%jpackage_script java_cup.Main "" "" %{real_name}:%{real_name}-runtime %{real_name} true

%if %{with bootstrap}
%files
%{_javadir}/%{real_name}*.jar
%else

%files -f .mfiles
%endif
%license licence.txt
%doc changelog.txt
%attr(0755,root,root) %{_bindir}/%{real_name}
%{_javadir}/java_cup*.jar

%if %{without bootstrap}
%files manual
%doc manual.html

%endif

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu May  4 2023 Frederic Crozat <fcrozat@suse.com>
- Add _multibuild to define additional spec files as additional
  flavors.
  Eliminates the need for source package links in OBS.
* Mon Mar 14 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * java-cup-classpath.patch
    + use the java-cup name instead of the java_cup one
- Regenerate the generated files with newer flex
* Fri Jan 14 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to recent git checkout providing 0.11 beta
- Modified patches:
  * java-cup-classpath.patch
  * java-cup-no-classpath-in-manifest.patch
  * java-cup-no-cup-no-jflex.patch
    + rediff to the changed context
- Removed patch:
  * java-cup-lr_parser-constructor.patch
    + integrated upstream
- Added patch:
  * java-cup-java8.patch
    + replace java 10+ constructs in order to be able to build
    with java 8
- Fetch sources using source service
- Do not run git during the build
* Fri Feb  1 2019 Fridrich Strba <fstrba@suse.com>
- BuildIgnore xml-commons-apis xml-commons-resolver xalan-j2
  and xerces-j2 in order to solve build cycle
* Fri Sep 15 2017 fstrba@suse.com
- Do not depend on java-gcj-compat
- Fix build with jdk9: specify source and target 1.6
* Thu Aug 29 2013 mvyskocil@suse.com
- Add conflicts for each variant
- Sync .changes
- Drop weird jpackage-prepare script and use standard pre_checkin.sh
* Fri Aug 23 2013 mvyskocil@suse.com
- Disable build of javadoc
  * drop java-cup-javadoc.patch
* Fri Jan 25 2013 coolo@suse.com
- sync licenses
* Mon Jun  4 2012 cfarrell@suse.com
- license update: HPND
  SPDX syntax
* Mon Nov  8 2010 mvyskocil@suse.cz
- Build ignore xml-comons-jax-1.3-apis
* Mon May 11 2009 mvyskocil@suse.cz
- Fixed bnc#501635: Added a lincense file
* Tue May  5 2009 mvyskocil@suse.cz
- Build using gcj (for proper bootstrap of openjdk)
* Wed Apr 29 2009 mvyskocil@suse.cz
- Initial packaging of java-cup-bootstrap 0.11 in SUSE (from jpp5)
